All of lore.kernel.org
 help / color / mirror / Atom feed
* [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf
@ 2009-06-05 11:29 Maciej Żenczykowski
  2009-06-15 12:11 ` Jean Delvare
                   ` (3 more replies)
  0 siblings, 4 replies; 5+ messages in thread
From: Maciej Żenczykowski @ 2009-06-05 11:29 UTC (permalink / raw)
  To: lm-sensors

[-- Attachment #1: Type: text/plain, Size: 464 bytes --]

Hi,

submitting a sensors.conf file for a Jetway NC92-330-LF motherboard
with f71882fg monitoring chip.

# uname -a
Linux gaia 2.6.29.4-168.mz1.fc11.x86_64 #1 SMP Fri Jun 5 11:10:05 CEST
2009 x86_64 x86_64 x86_64 GNU/Linux

# lsmod | head -n 5
Module                  Size  Used by
f71882fg               27120  0
coretemp                6768  0

Also including a slight patch to coretemp.c for atom support.

Hope you include the conf in the wiki.
Thanks,
Maciej

[-- Attachment #2: sensors3.conf --]
[-- Type: application/octet-stream, Size: 1904 bytes --]

# Jetway NC92-330-LF

chip "f71862fg-*"

    label in0 "Vcc3V"
    label in1 "Vcore"
    label in2 "   NB"
    label in3 "+ 5V"
    label in4 "+12V"
    label in5 "5VSB"
    label in6 "VDIMM"
    label in7 "VSB3V"
    label in8 "Vbat"

    label fan1 "CPUFAN"
    label fan2 "SYSFAN1"
    label fan3 "SYSFAN2"

    label temp1 "?CPU Temp"
    label temp2 "?Sys Temp"
    label temp3 "???? Temp"

# According to datasheet, 3VCC/VSB/VBAT
# (ie. Vcc3V/VSB3V/Vbat, or in0/in7/in8)
# use internal R1=R2=150K Ohm resistors
#
# remember V_in_to_chip = V_real * R2 / (R1 + R2)
# (where V_real----R1---*----V_in_to_chip) [max 2.048V]
# (                     |                )
# (                    R2                )
# (                     |                )
# (                    GND               )
#
# It would seem that VDIMM is the same...
# Hence those four are set to use "@*2, @/2"
#
# The values of 5.25 for +5V and 5VSB and 11 for +12V
# are from the datasheet as well (after juggling):
#
# VCORE    R1=1K   R2=inf VCORE  -> *1
# VRAM     R1=10K  R2=10K VIN2   -> *2
# VCHIPSET R1=4.7K R2=10K VIN3   -> *1.47
# VCC5V    R1=20K  R2=4.7 VIN4   -> *5.255319148
# +12V     R1=200K R2=20K VIN5   -> *11
# VCC1.5V  R1=10K  R2=inf VIN6   -> *1

    compute in0 @*2, @/2
    compute in1 @, @
    compute in2 @, @
    compute in3 @*5.255319148, @/5.255319148
    compute in4 @*11, @/11
    compute in5 @*5.255319148, @/5.255319148
    compute in6 @*2, @/2
    compute in7 @*2, @/2
    compute in8 @*2, @/2

#   set temp1_type 2
    set temp1_max        85
    set temp1_max_hyst   81
    set temp1_crit       65
#   set temp1_crit_hyst  61
#   set temp2_type 2
    set temp2_max        85
    set temp2_max_hyst   81
    set temp2_crit      100
#   set temp2_crit_hyst  96
#   set temp3_type 2
    set temp3_max        70
    set temp3_max_hyst   68
    set temp3_crit       85
#   set temp3_crit_hyst  83


[-- Attachment #3: linux-2.6-mz-atom_coretemp.patch --]
[-- Type: application/octet-stream, Size: 3254 bytes --]

diff -Naur vanilla-2.6.29/Documentation/hwmon/coretemp vanilla-2.6.29.coretemp/Documentation/hwmon/coretemp
--- vanilla-2.6.29/Documentation/hwmon/coretemp	2009-03-24 00:12:14.000000000 +0100
+++ vanilla-2.6.29.coretemp/Documentation/hwmon/coretemp	2009-06-05 09:37:21.263124574 +0200
@@ -4,7 +4,7 @@
 Supported chips:
   * All Intel Core family
     Prefix: 'coretemp'
-    CPUID: family 0x6, models 0xe, 0xf, 0x16, 0x17
+    CPUID: family 0x6, models 0xe, 0xf, 0x16, 0x17, 0x1c
     Datasheet: Intel 64 and IA-32 Architectures Software Developer's Manual
                Volume 3A: System Programming Guide
                http://softwarecommunity.intel.com/Wiki/Mobility/720.htm
@@ -14,10 +14,11 @@
 Description
 -----------
 
-This driver permits reading temperature sensor embedded inside Intel Core CPU.
-Temperature is measured in degrees Celsius and measurement resolution is
-1 degree C. Valid temperatures are from 0 to TjMax degrees C, because
-the actual value of temperature register is in fact a delta from TjMax.
+This driver permits reading temperature sensor embedded inside Intel
+Core and Intel Atom CPUs. Temperature is measured in degrees Celsius
+and measurement resolution is 1 degree C. Valid temperatures are from 0
+to TjMax degrees C, because the actual value of temperature register is
+in fact a delta from TjMax.
 
 Temperature known as TjMax is the maximum junction temperature of processor.
 Intel defines this temperature as 85C or 100C. At this temperature, protection
@@ -35,4 +36,5 @@
 
 The TjMax temperature is set to 85 degrees C if undocumented model specific
 register (UMSR) 0xee has bit 30 set. If not the TjMax is 100 degrees C as
-(sometimes) documented in processor datasheet.
+(sometimes) documented in processor datasheet. The Intel Atom has TjMax 95C
+as per the specification.
diff -Naur vanilla-2.6.29/drivers/hwmon/coretemp.c vanilla-2.6.29.coretemp/drivers/hwmon/coretemp.c
--- vanilla-2.6.29/drivers/hwmon/coretemp.c	2009-03-24 00:12:14.000000000 +0100
+++ vanilla-2.6.29.coretemp/drivers/hwmon/coretemp.c	2009-06-05 10:09:02.206624345 +0200
@@ -1,7 +1,8 @@
 /*
  * coretemp.c - Linux kernel module for hardware monitoring
  *
- * Copyright (C) 2007 Rudolf Marek <r.marek@assembler.cz>
+ * Copyright (C) 2007, 2008 Rudolf Marek <r.marek@assembler.cz>
+ * Atom patch ported by Maciej Zenczykowski <zenczykowski@gmail.com>
  *
  * Inspired from many hwmon drivers
  *
@@ -161,6 +162,13 @@
 	int err;
 	u32 eax, edx;
 
+	/* Intel Atom has a fixed TjMax at 95C */
+	if (c->x86_model == 0x1c) {
+		tjmax = 95000;
+		ismobile = 0;
+		return tjmax;
+	}
+	
 	/* Early chips have no MSR for TjMax */
 
 	if ((c->x86_model == 0xf) && (c->x86_mask < 4)) {
@@ -413,11 +421,11 @@
 	for_each_online_cpu(i) {
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
 		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
 			(c->x86_model == 0x16) || (c->x86_model == 0x17) ||
-			(c->x86_model == 0x1A))) {
+			(c->x86_model == 0x1a) || (c->x86_model == 0x1c))) {
 
 			/* supported CPU not found, but report the unknown
 			   family 6 CPU */

[-- Attachment #4: Type: text/plain, Size: 153 bytes --]

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2009-06-15 14:59 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
@@ -413,11 +421,11 @@
 		struct cpuinfo_x86 *c = &cpu_data(i);
 
-		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1A */
+		/* check if family 6, models 0xe, 0xf, 0x16, 0x17, 0x1a, 0x1c */
 		if ((c->cpuid_level < 0) || (c->x86 != 0x6) ||
 		    !((c->x86_model == 0xe) || (c->x86_model == 0xf) ||
2009-06-05 11:29 [lm-sensors] Jetway NC92-330-LF motherboard sensors.conf Maciej Żenczykowski
2009-06-15 12:11 ` Jean Delvare
2009-06-15 14:27 ` Maciej Żenczykowski
2009-06-15 14:29 ` Maciej Żenczykowski
2009-06-15 14:59 ` Maciej Żenczykowski

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.